package com.ozs.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.utils.StringUtils;
import com.ozs.entity.BaseVehicleTerminal;
import com.ozs.entity.vo.BaseVehicleTerminalVo;
import com.ozs.mapper.BaseVehicleTerminalMapper;
import com.ozs.service.BaseVehicleTerminalService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 机车车载终端信息表 服务实现类
 * </p>
 *
 * @author ozs
 * @since 2023-04-11
 */
@Service
public class BaseVehicleTerminalServiceImpl extends ServiceImpl<BaseVehicleTerminalMapper, BaseVehicleTerminal> implements BaseVehicleTerminalService {

    @Autowired
    private BaseVehicleTerminalMapper baseVehicleTerminalMapper;

    @Override
    public IPage<BaseVehicleTerminal> vehicleTerminalList(BaseVehicleTerminalVo baseVehicleTerminalleVo) {
        LambdaQueryWrapper<BaseVehicleTerminal> wrapper = new LambdaQueryWrapper<BaseVehicleTerminal>();
        if (!StringUtils.isEmptySunhh(baseVehicleTerminalleVo) && !StringUtils.isEmptySunhh(baseVehicleTerminalleVo.getTerminalCode())) {
            wrapper.eq(BaseVehicleTerminal::getTerminalCode, baseVehicleTerminalleVo.getTerminalCode());
        }
        if (!StringUtils.isEmptySunhh(baseVehicleTerminalleVo) && !StringUtils.isEmptySunhh(baseVehicleTerminalleVo.getTerminalName())) {
            wrapper.eq(BaseVehicleTerminal::getTerminalName, baseVehicleTerminalleVo.getTerminalName());
        }
        if (!StringUtils.isEmptySunhh(baseVehicleTerminalleVo) && !StringUtils.isEmptySunhh(baseVehicleTerminalleVo.getStatus())) {
            wrapper.eq(BaseVehicleTerminal::getStatus, baseVehicleTerminalleVo.getStatus());
        }
        int pageNum = Integer.parseInt(baseVehicleTerminalleVo.getPageNum().toString());
        int pageSize = Integer.parseInt(baseVehicleTerminalleVo.getPageSize().toString());
        com.github.pagehelper.Page<BaseVehicleTerminal> page = PageHelper.startPage(pageNum, pageSize)
                .doSelectPage(() -> baseVehicleTerminalMapper.selectList(wrapper));
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<BaseVehicleTerminal> pageR =
                new com.baomidou.mybatisplus.extension.plugins.pagination.Page<>(pageNum, pageSize);
        pageR.setRecords(page.getResult());
        pageR.setTotal(page.getTotal());
        return pageR;
    }

    @Override
    public AjaxResult baseVehicleTerminalDetails(BaseVehicleTerminalVo baseVehicleTerminalVo) {
        BaseVehicleTerminal baseVehicleTerminal = baseVehicleTerminalMapper.selectById(baseVehicleTerminalVo.getId());
        return AjaxResult.success(baseVehicleTerminal);
    }

    @Override
    public AjaxResult vehicleTerminalAdd(BaseVehicleTerminal baseVehicleTerminal, String userId) {
        LambdaQueryWrapper<BaseVehicleTerminal> wrapper = new LambdaQueryWrapper<BaseVehicleTerminal>();
        if (!StringUtils.isEmptySunhh(baseVehicleTerminal) && !StringUtils.isEmptySunhh(baseVehicleTerminal.getTerminalCode())) {
            wrapper.eq(BaseVehicleTerminal::getTerminalCode, baseVehicleTerminal.getTerminalCode());
        }
        List<BaseVehicleTerminal> baseVehicles = baseVehicleTerminalMapper.selectList(wrapper);
        if (baseVehicles.size() > 0) {
            return AjaxResult.error("车载终端编码已存在！");
        }
        Date date = new Date();
        baseVehicleTerminal.setCreateBy(userId);
        baseVehicleTerminal.setUpdateBy(userId);
        baseVehicleTerminal.setCreateTime(date);
        baseVehicleTerminal.setUpdateTime(date);
        int insert = baseVehicleTerminalMapper.insert(baseVehicleTerminal);
        if (insert > 0) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error();
        }
    }

    @Override
    public AjaxResult vehicleTerminalUpdate(BaseVehicleTerminal baseVehicleTerminal, String userId) {
        LambdaQueryWrapper<BaseVehicleTerminal> wrapper = new LambdaQueryWrapper<BaseVehicleTerminal>();
        if (!StringUtils.isEmptySunhh(baseVehicleTerminal) && !StringUtils.isEmptySunhh(baseVehicleTerminal.getTerminalCode())) {
            wrapper.eq(BaseVehicleTerminal::getTerminalCode, baseVehicleTerminal.getTerminalCode());
        }
        List<BaseVehicleTerminal> baseVehicles = baseVehicleTerminalMapper.selectList(wrapper);
        if (baseVehicles.size() > 0) {
            return AjaxResult.error("机车编码已存在！");
        }
        baseVehicleTerminal.setUpdateBy(userId);
        baseVehicleTerminal.setUpdateTime(new Date());
        int update = baseVehicleTerminalMapper.updateById(baseVehicleTerminal);
        if (update > 0) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error();
        }
    }
}
